package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.WyPlatformFeaturePage;

/**
 * 专题页Mapper接口
 * 
 * @author ruoyi
 * @date 2025-01-06
 */
public interface WyPlatformFeaturePageMapper 
{
    /**
     * 查询专题页
     * 
     * @param id 专题页主键
     * @return 专题页
     */
    public WyPlatformFeaturePage selectWyPlatformFeaturePageById(Long id);

    /**
     * 查询专题页列表
     * 
     * @param wyPlatformFeaturePage 专题页
     * @return 专题页集合
     */
    public List<WyPlatformFeaturePage> selectWyPlatformFeaturePageList(WyPlatformFeaturePage wyPlatformFeaturePage);

    /**
     * 新增专题页
     * 
     * @param wyPlatformFeaturePage 专题页
     * @return 结果
     */
    public int insertWyPlatformFeaturePage(WyPlatformFeaturePage wyPlatformFeaturePage);

    /**
     * 修改专题页
     * 
     * @param wyPlatformFeaturePage 专题页
     * @return 结果
     */
    public int updateWyPlatformFeaturePage(WyPlatformFeaturePage wyPlatformFeaturePage);

    /**
     * 删除专题页
     * 
     * @param id 专题页主键
     * @return 结果
     */
    public int deleteWyPlatformFeaturePageById(Long id);

    /**
     * 批量删除专题页
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWyPlatformFeaturePageByIds(Long[] ids);
}
